import { resolveAttr, resolveLanguage } from '../utils.js';
export const preWrapperPlugin = (md, { preWrapper = true } = {}) => {
    const rawFence = md.renderer.rules.fence;
    md.renderer.rules.fence = (...args) => {
        const [tokens, idx, options] = args;
        const token = tokens[idx];
        // get token info
        const info = token.info ? md.utils.unescapeAll(token.info).trim() : '';
        const lang = resolveLanguage(info);
        const title = resolveAttr(info, 'title') || lang;
        const languageClass = `${options.langPrefix}${lang}`;
        let result = rawFence(...args);
        if (!preWrapper) {
            // remove `<code>` attributes
            result = result.replace(/<code[^]*?>/, '<code>');
            result = `<pre class="${languageClass}"${result.slice('<pre'.length)}`;
            return result;
        }
        return `<div class="${languageClass}" data-ext="${lang}" data-title="${title}">${result}</div>`;
    };
};
